@@ -62,6 +62,10 @@ class CloudRegion(Enum):
     AZURE_US_WEST = "AZURE_US_WEST"
     AZURE_US_WEST2 = "AZURE_US_WEST2"
     AZURE_US_SOUTH_CENTRAL = "AZURE_US_SOUTH_CENTRAL"
+    AKAMAI_BR_GRU = "AKAMAI_BR_GRU"
+    AKAMAI_FR_PAR = "AKAMAI_FR_PAR"
+    AKAMAI_JP_OSA = "AKAMAI_JP_OSA"
+    AKAMAI_US_SEA = "AKAMAI_US_SEA"
     NORTH_AMERICA = "NORTH_AMERICA"
     SOUTH_AMERICA = "SOUTH_AMERICA"
     EUROPE = "EUROPE"
