@@ -4,9 +4,10 @@ from __future__ import absolute_import
 
 from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
-from bitmovin_api_sdk.streams.search.search_api import SearchApi
 from bitmovin_api_sdk.streams.video.video_api import VideoApi
 from bitmovin_api_sdk.streams.live.live_api import LiveApi
+from bitmovin_api_sdk.streams.search.search_api import SearchApi
+from bitmovin_api_sdk.streams.signing_keys.signing_keys_api import SigningKeysApi
 
 
 class StreamsApi(BaseApi):
@@ -21,13 +22,6 @@ class StreamsApi(BaseApi):
             logger=logger
         )
 
-        self.search = SearchApi(
-            api_key=api_key,
-            tenant_org_id=tenant_org_id,
-            base_url=base_url,
-            logger=logger
-        )
-
         self.video = VideoApi(
             api_key=api_key,
             tenant_org_id=tenant_org_id,
@@ -41,3 +35,17 @@ class StreamsApi(BaseApi):
             base_url=base_url,
             logger=logger
         )
+
+        self.search = SearchApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
+
+        self.signing_keys = SigningKeysApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
